@@ -42,7 +42,7 @@ def about ():
 DEFAULT_CONFIG_FNAME = '/etc/repochecker/binsym.yaml'
 configfile = DEFAULT_CONFIG_FNAME
 
-def load_config (filename = DEFAULT_CONFIG_FNAME):
+def load_config (filename):
   """
   @brief Load configuration from a given yaml file
 
@@ -59,7 +59,7 @@ def load_config (filename = DEFAULT_CONFIG_FNAME):
     cfg = yaml.load (file (filename, 'r'), Loader=yaml.loader.BaseLoader)
   except:
     cfg = gen_config()
-    save_config (cfg)
+    save_config (cfg, configfile)
   return cfg
 
 def gen_config ():
@@ -79,7 +79,7 @@ def gen_config ():
                  'package-extensions' : tuple(['.rpm'])})
   return config
 
-def save_config (config, filename = DEFAULT_CONFIG_FNAME):
+def save_config (config, filename):
   """
   @brief save config to a given file
 
